# Crystallography in EasyScience

## About

**EasyCrystallography** is a Python library used within the [EasyScience]
framework to generate and manipulate crystal structures.

## License

**EasyCrystallography** is licensed under the [BSD 3-Clause License].

## Latest release

The latest release of **EasyCrystallography** is [{{ ec_latest_version }}].

<!-- prettier-ignore-start -->
[BSD 3-Clause License]: https://github.com/EasyScience/EasyCrystallography/blob/master/LICENSE
[EasyScience]: https://easyscience.software
[{{ ec_latest_version }}]: https://github.com/EasyScience/EasyCrystallography/releases/latest
<!-- prettier-ignore-end -->
